/* ========================================
 *
 * Copyright YOUR COMPANY, THE YEAR
 * All Rights Reserved
 * UNPUBLISHED, LICENSED SOFTWARE.
 *
 * CONFIDENTIAL AND PROPRIETARY INFORMATION
 * WHICH IS THE PROPERTY OF your company.
 *
 * ========================================
*/
#include <project.h>

#define LSBperGee 16384.0       //from the register map, for the +/- 2 G setting, there are 16384 LSB's per gee

void MPU_ByteWrite(uint8_t reg, uint8_t byte);      //ByteWrite function prototype

uint8_t topByte;        //we'll use these to hold and process the data from the MPU
uint8_t bottomByte;
uint16_t combinedData;
float geeForce;

int main()
{
    CyGlobalIntEnable;          //Enable Global Interrupts

    I2C_MASTER_1_Start();       //Start the I2C Master
    
    /*
    The steps for writing a single byte over I2C is as follows:
    1- Master sends a start condition
    2- Master sends write bit + I2C Address
    3- Peripheral sends ACK
    4-Master sends data byte
    5- Peripheral sends ACK
    6- Master sends stop condition
    
    Check the datasheet for the exact procedure for a given chip.
    
    To write a register on the MPU 6050 you must:
    1- send start condition
    2- write + I2C address
    3- send register address
    4- send databyte
    5- send stop condition
    */
    
    
    I2C_MASTER_1_MasterSendStart(0x68, 0);      //starts an I2C write. The address of the MPU is 0x68
    I2C_MASTER_1_MasterWriteByte(0x1A);         //writes the address of the target register. 1A is the CONFIG register
    I2C_MASTER_1_MasterWriteByte(0x00);         //writes sets the frame sync to disabled and the DLPF to a bandwidth of 260 Hz
    I2C_MASTER_1_MasterSendStop();              //stops an I2C transaction.
    
    /*Since it's the same procedure for every single-register write on this chip, this procedure has
      been wrapped into a helper function, void MPU_ByteWrite(uint8_t I2CAddress, uint8_t dataByte).
    */
    
    
    MPU_ByteWrite(0x6B, 0x00);  //takes the MPU out of sleep mode
    MPU_ByteWrite(0x1C, 0x00);  //sets the accelerometer to +/- 2 gees range
    MPU_ByteWrite(0x23, 0x00);  //disables FIFO buffer and DLPF
    
    
    for(;;)
    {
    I2C_MASTER_1_MasterSendStart(0x68, 0);      //start the transaction
    I2C_MASTER_1_MasterWriteByte(0x3B);         //The register address for the X-acceleration is 0x3B
    I2C_MASTER_1_MasterSendRestart(0x68, 1);    //MasterSendRestart sends another start condition without needing to send a stop condition first
    
    topByte = I2C_MASTER_1_MasterReadByte(I2C_MASTER_1_ACK_DATA);       //receive the first byte and acknowledge to signal we are not done reading
    bottomByte = I2C_MASTER_1_MasterReadByte(I2C_MASTER_1_NAK_DATA);    //receive the second byte and non-acknowledge to signal we are done reading
    
    I2C_MASTER_1_MasterSendStop();      //end the transaction
    
    combinedData = ((uint16_t)topByte << 8) | (uint16_t)bottomByte;     //combine the two bytes into one 16-bit unsigned integer

    geeForce = (int16_t)combinedData / LSBperGee;
    
    if (geeForce > .25) LED_Write(1);   //if the acceleration is above the threshold turn the LED on
    else LED_Write(0);                  //otherwise, turn off the LED
    
    }
}

void MPU_ByteWrite(uint8_t reg, uint8_t byte){
    /* Writes a single Byte to the I2C device at address 0x68.
    parameters:
        uint8_t reg: the register on the device to write to
        uint8_t byte: the byte to be written
    
    returns:
        void
    */
    
    I2C_MASTER_1_MasterSendStart(0x68, 0);      //start a write to the MPU to begin the transaction
    I2C_MASTER_1_MasterWriteByte(reg);          //send the address of the register we want to write to
    I2C_MASTER_1_MasterWriteByte(byte);         //send the byte
    I2C_MASTER_1_MasterSendStop();              //send the stop signal to end the transaction
}


/* [] END OF FILE */
